==> haskell-minimorph-0.3.0.1-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-minimorph.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 minimorph
version:              0.3.0.1
visibility:           public
id:                   minimorph-0.3.0.1-Kg7S5DMQXdwQAH2c8j5fv
key:                  minimorph-0.3.0.1-Kg7S5DMQXdwQAH2c8j5fv
license:              BSD-3-Clause
maintainer:           Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:               Eric Kow
homepage:             https://github.com/Mikolaj/minimorph
synopsis:             English spelling functions with an emphasis on simplicity.
description:
    A set of simplistic functions capturing the more regular
    parts of English spelling (for generation, not parsing).
    You will need to complement this with some account for
    irregular nouns/verbs. This package is not meant to provide
    anything resembling a full account of English morphology
    (something like Functional Morphology or sequor could be
    better suited). The main goal is to provide something cheap
    and cheerful with no learning curve, that you can use until
    your application calls for more robustness.
    See <https://github.com/Mikolaj/miniutter> for a simple
    use case.

category:             Natural Language Processing
abi:                  ffaa92fa87986a908ef1b1db5e7aa616
exposed:              True
exposed-modules:
    NLP.Minimorph.English NLP.Minimorph.Number NLP.Minimorph.Util

import-dirs:          /usr/lib/ghc-9.0.2/site-local/minimorph-0.3.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/minimorph-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-minimorph
hs-libraries:         HSminimorph-0.3.0.1-Kg7S5DMQXdwQAH2c8j5fv
depends:              base-4.15.1.0 text-1.2.5.0
haddock-interfaces:   /usr/share/doc/haskell-minimorph/html/minimorph.haddock
haddock-html:         /usr/share/doc/haskell-minimorph/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-minimorph-0.3.0.1-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-minimorph.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 minimorph
version:              0.3.0.1
visibility:           public
id:                   minimorph-0.3.0.1-Gxd7YZJhZia95JAjAGl7nD
key:                  minimorph-0.3.0.1-Gxd7YZJhZia95JAjAGl7nD
license:              BSD-3-Clause
maintainer:           Mikolaj Konarski <mikolaj.konarski@funktory.com>
author:               Eric Kow
homepage:             https://github.com/Mikolaj/minimorph
synopsis:             English spelling functions with an emphasis on simplicity.
description:
    A set of simplistic functions capturing the more regular
    parts of English spelling (for generation, not parsing).
    You will need to complement this with some account for
    irregular nouns/verbs. This package is not meant to provide
    anything resembling a full account of English morphology
    (something like Functional Morphology or sequor could be
    better suited). The main goal is to provide something cheap
    and cheerful with no learning curve, that you can use until
    your application calls for more robustness.
    See <https://github.com/Mikolaj/miniutter> for a simple
    use case.

category:             Natural Language Processing
abi:                  11a1a5863438f7708023e6cbd68c151e
exposed:              True
exposed-modules:
    NLP.Minimorph.English NLP.Minimorph.Number NLP.Minimorph.Util

import-dirs:          /usr/lib/ghc-9.0.2/site-local/minimorph-0.3.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/minimorph-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-minimorph
hs-libraries:         HSminimorph-0.3.0.1-Gxd7YZJhZia95JAjAGl7nD
depends:              base-4.15.1.0 text-1.2.5.0
haddock-interfaces:   /usr/share/doc/haskell-minimorph/html/minimorph.haddock
haddock-html:         /usr/share/doc/haskell-minimorph/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
